
#ifndef CALENDAR_EXPORT_H
#define CALENDAR_EXPORT_H

#ifdef CALENDAR_STATIC_DEFINE
#  define CALENDAR_EXPORT
#  define CALENDAR_NO_EXPORT
#else
#  ifndef CALENDAR_EXPORT
#    ifdef MauiKitCalendar4_EXPORTS
        /* We are building this library */
#      define CALENDAR_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define CALENDAR_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef CALENDAR_NO_EXPORT
#    define CALENDAR_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef CALENDAR_DEPRECATED
#  define CALENDAR_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef CALENDAR_DEPRECATED_EXPORT
#  define CALENDAR_DEPRECATED_EXPORT CALENDAR_EXPORT CALENDAR_DEPRECATED
#endif

#ifndef CALENDAR_DEPRECATED_NO_EXPORT
#  define CALENDAR_DEPRECATED_NO_EXPORT CALENDAR_NO_EXPORT CALENDAR_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef CALENDAR_NO_DEPRECATED
#    define CALENDAR_NO_DEPRECATED
#  endif
#endif

#endif /* CALENDAR_EXPORT_H */
