// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef Calendar_VERSION_H
#define Calendar_VERSION_H

#define Calendar_VERSION_STRING "4.0.2"
#define Calendar_VERSION_MAJOR 4
#define Calendar_VERSION_MINOR 0
#define Calendar_VERSION_PATCH 2
#define Calendar_VERSION ((4<<16)|(0<<8)|(2))

#endif
